import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-AtomInput-input';
var SIZES = {
  MEDIUM: 'm',
  SMALL: 's',
  XSMALL: 'xs'
};
var ERROR_STATES = {
  ERROR: 'error',
  SUCCESS: 'success'
};

var getClassNames = function getClassNames(_ref) {
  var size = _ref.size,
      charsSize = _ref.charsSize,
      hideInput = _ref.hideInput,
      noBorder = _ref.noBorder,
      readOnly = _ref.readOnly,
      errorState = _ref.errorState;
  return cx(BASE_CLASS, BASE_CLASS + "-" + size, charsSize && BASE_CLASS + "--size", hideInput && BASE_CLASS + "--hidden", noBorder && BASE_CLASS + "--noBorder", readOnly && BASE_CLASS + "--readOnly", errorState && BASE_CLASS + "--" + ERROR_STATES.ERROR, errorState === false && BASE_CLASS + "--" + ERROR_STATES.SUCCESS);
};

var Input = function Input(_ref2) {
  var disabled = _ref2.disabled,
      readOnly = _ref2.readOnly,
      hideInput = _ref2.hideInput,
      noBorder = _ref2.noBorder,
      id = _ref2.id,
      name = _ref2.name,
      onBlur = _ref2.onBlur,
      onFocus = _ref2.onFocus,
      placeholder = _ref2.placeholder,
      reference = _ref2.reference,
      size = _ref2.size,
      errorState = _ref2.errorState,
      type = _ref2.type,
      value = _ref2.value,
      charsSize = _ref2.charsSize,
      tabIndex = _ref2.tabIndex,
      maxLength = _ref2.maxLength,
      minLength = _ref2.minLength,
      autoComplete = _ref2.autoComplete,
      onChange = _ref2.onChange,
      onEnter = _ref2.onEnter,
      onEnterKey = _ref2.onEnterKey,
      onKeyDown = _ref2.onKeyDown,
      required = _ref2.required,
      pattern = _ref2.pattern;

  var changeHandler = function changeHandler(ev) {
    var _ev$target = ev.target,
        value = _ev$target.value,
        name = _ev$target.name;
    onChange(ev, {
      value: value,
      name: name
    });
  };

  var handleKeyDown = function handleKeyDown(ev) {
    var _ev$target2 = ev.target,
        value = _ev$target2.value,
        name = _ev$target2.name;
    var key = ev.key;
    onKeyDown(ev, {
      value: value,
      name: name
    });
    if (key === onEnterKey) onEnter(ev, {
      value: value,
      name: name
    });
  };

  var className = getClassNames({
    size: size,
    charsSize: charsSize,
    hideInput: hideInput,
    noBorder: noBorder,
    readOnly: readOnly,
    errorState: errorState
  });
  return React.createElement("input", {
    className: className,
    tabIndex: tabIndex,
    disabled: disabled || readOnly,
    readOnly: readOnly,
    id: id,
    name: name,
    onChange: changeHandler,
    onFocus: onFocus,
    onBlur: onBlur,
    onKeyDown: handleKeyDown,
    placeholder: placeholder,
    ref: reference,
    type: type,
    value: value,
    size: charsSize,
    maxLength: maxLength,
    minLength: minLength,
    autoComplete: autoComplete,
    required: required,
    pattern: pattern
  });
};

Input.defaultProps = {
  size: SIZES.MEDIUM,
  onEnterKey: 'Enter',
  tabIndex: -1,
  onKeyDown: function onKeyDown() {},
  onEnter: function onEnter() {},
  onChange: function onChange() {}
};
export default Input;
export { SIZES as inputSizes };